@@ -6,6 +6,7 @@
 """
 import os
 import time
+import asyncmongo
 import tornado.gen as gen
 
 from threading import local
@@ -45,7 +46,7 @@ class ContextHandler(object):
         if __conf__.REDIS_SESSION:
             return get_context().redis_session(_id, key, val)
         else:
-            get_context().session(_id, key, val)
+            return get_context().session(_id, key, val)
 
 
 class LogicContext(object):
@@ -54,9 +55,9 @@ class LogicContext(object):
     """
     _thread_local = local()
 
-    def __init__(self, cache_host=None, db_host=None):
-        self._cache_host = cache_host or __conf__.CACHE_HOST
-        self._db_host = db_host or __conf__.DB_HOST
+    def __init__(self, redis_host=None, mongo_host=None):
+        self._redis_host = redis_host or __conf__.CACHE_HOST
+        self._mongo_host = mongo_host or __conf__.DB_HOST
         self._db_conn = None
         self._sync_db = None
         self._motor_clt = None
@@ -79,7 +80,7 @@ class LogicContext(object):
 
     def get_redis(self):
         ''' get redis from context '''
-        host = self._cache_host
+        host = self._redis_host
         h, p = host.split(":") if ":" in host else (host, 6379)
         cache = Redis(
             host=h, port=int(p), socket_timeout=__conf__.SOCK_TIMEOUT)
@@ -92,7 +93,7 @@ class LogicContext(object):
 
     def get_mongo(self, name=None):
         '''
-        get mongodb by connection
+        get temp  mongodb by connection
         '''
         name = name or __conf__.DB_NAME
         if not self._db_conn:
@@ -102,6 +103,13 @@ class LogicContext(object):
         return self._db_conn[name]
     
 
+    def get_asyncmongo(self, name=None):
+        name = name or __conf__.DB_NAME
+        if not hasattr(self,'_async_db'):
+            self._async_db = asyncmongo.Client(pool_id='kpages_db', host=__conf__.DB_HOST, port=27017,dbname=name)
+
+        return self._async_db
+
     def get_async_mongo(self, name=None):
         """ get motor client"""
         name = name or __conf__.DB_NAME
@@ -117,7 +125,7 @@ class LogicContext(object):
         name = name or __conf__.DB_NAME
         if not self._motor_clt:
             result, err = (yield gen.Task(
-                motor.MotorClient(host=self._db_host).open, )).args
+                motor.MotorClient(host=self._mongo_host).open, )).args
             if err:
                 raise err
             self._motor_clt = result
@@ -168,6 +176,8 @@ class LogicContext(object):
         get redis clinet in application 
         """
         if not hasattr(cls,'__redisclient__'):
+            host = __conf__.CACHE_HOST
+            h, p = host.split(":") if ":" in host else (host, 6379)
             cp = ConnectionPool(host=h, port=int(p), socket_timeout=__conf__.SOCK_TIMEOUT)
             cls.__redisclient__ = Redis(connection_pool=cp)
         
